@@ -124,6 +124,14 @@ class TalismanAPIAdapter:
     def get_tdm_builder(self) -> AbstractTdmBuilder:
         return self.tdm_builder
 
+    @property
+    def type_mapping(self):
+        return self._type_mapping
+
+    @type_mapping.setter
+    def type_mapping(self, new_type_mapping: TypeMapping):
+        self._type_mapping = new_type_mapping
+
     @property
     def limit(self):
         return self._limit
